import { AccountAddress, ChainAddress, ChainsConfig, Contracts, Network, Platform, Signer, TokenAddress, TokenId, VAA } from '@wormhole-foundation/connect-sdk';
import { EvmChains, EvmUnsignedTransaction } from '@wormhole-foundation/connect-sdk-evm';
import { Provider, ethers } from 'ethers';
import { EvmWormholeCore } from '@wormhole-foundation/connect-sdk-evm-core';
import '@wormhole-foundation/connect-sdk-evm-tokenbridge';
export declare class EvmPorticoBridge<N extends Network, C extends EvmChains = EvmChains> {
    readonly network: N;
    readonly chain: C;
    readonly provider: Provider;
    readonly contracts: Contracts;
    readonly core: EvmWormholeCore<N, C>;
    chainId: bigint;
    porticoAddress: string;
    uniswapAddress: string;
    porticoContract: ethers.Contract;
    uniswapContract: ethers.Contract;
    constructor(network: N, chain: C, provider: Provider, contracts: Contracts, core: EvmWormholeCore<N, C>);
    static fromRpc<N extends Network>(provider: Provider, config: ChainsConfig<N, Platform>): Promise<EvmPorticoBridge<N, EvmChains>>;
    transfer(sender: AccountAddress<C>, receiver: ChainAddress, token: TokenAddress<C>, amount: bigint, destToken: TokenId | 'native', swapAmounts: {
        minAmountStart: bigint;
        minAmountFinish: bigint;
        amountFinish: bigint;
    }, relayerFee: bigint): AsyncGenerator<EvmUnsignedTransaction<N, "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky">, void, unknown>;
    redeem(vaa: VAA, signer: Signer<N>): AsyncGenerator<EvmUnsignedTransaction<N, "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky">, void, unknown>;
    quoteSwap(input: TokenAddress<C>, output: TokenAddress<C>, amount: bigint): Promise<bigint>;
    quoteRelay(token: TokenAddress<C>, destination: TokenId): Promise<bigint>;
    private approve;
    private createUnsignedTransaction;
}
//# sourceMappingURL=porticoBridge.d.ts.map