"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOriginalEthereumAddress = exports.isEqualCaseInsensitive = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const isEqualCaseInsensitive = (a, b) => {
    return a.toLowerCase() === b.toLowerCase();
};
exports.isEqualCaseInsensitive = isEqualCaseInsensitive;
// For a given token, return the corresponding address native to Ethereum
// Only considers local cache
const getOriginalEthereumAddress = (network, token) => {
    if (token.chain === 'Ethereum')
        return token;
    const tokenAddress = (0, connect_sdk_1.canonicalAddress)(token);
    const tokenData = connect_sdk_1.tokens.getTokenByAddress(network, token.chain, tokenAddress);
    if (!tokenData)
        throw new Error('Could not find token symbol for ' + tokenAddress);
    const originalToken = connect_sdk_1.tokens.getCanonicalToken(network, token.chain, tokenData.symbol);
    if (!originalToken)
        throw new Error('Could not find original token for ' + tokenAddress);
    if (originalToken.chain !== 'Ethereum')
        throw new Error('Original token does not come from Ethereum');
    return connect_sdk_1.Wormhole.chainAddress(originalToken.chain, originalToken.address);
};
exports.getOriginalEthereumAddress = getOriginalEthereumAddress;
//# sourceMappingURL=utils.js.map